@@ -57,26 +57,23 @@ from lino import dd
 #~ from lino.utils import Warning
 from lino.utils import join_words
 from lino.utils import AttrDict, IncompleteDate
-from lino.core.modeltools import obj2str
+#~ from lino.core.dbutils import obj2str
 
-from lino.utils import babel
 from lino.utils.choosers import chooser
 from lino.utils.ssin import ssin_validator
 
 from lino.utils.xmlgen import html as xghtml
 
 #~ from lino.utils import dblogger
-#~ from lino.core.modeltools import resolve_model
+#~ from lino.core.dbutils import resolve_model
 #~ from lino.utils.xmlgen import etree
 #~ from lino.utils.xmlgen import cbss
 
-from lino.utils.babel import dtos
-
 #~ from lino.utils.choicelists import ChoiceList
 #~ from lino.utils.choicelists import Gender
 #~ from lino.modlib.users.models import UserLevels
 #~ from lino.modlib.contacts import models as contacts
-from lino.core.modeltools import makedirs_if_missing
+#~ from lino.core.dbutils import makedirs_if_missing
 #~ from lino.mixins.printable import DirectPrintAction
 
 from lino_welfare.modlib.pcsw import models as pcsw
@@ -146,8 +143,8 @@ def cbss2civilstate(node):
     if not value:
         return value
     v = pcsw.CivilState.get_by_value(value)
-    if v is None:
-        print "20120601 cbss2civilstate None for ", repr(value)
+    #~ if v is None:
+        #~ print "20120601 cbss2civilstate None for ", repr(value)
     return unicode(v)
     
 def nodetext(node):
@@ -255,7 +252,7 @@ class unused_ExecuteRequest(dd.RowAction):
 
 
 
-class Sector(babel.BabelNamed):
+class Sector(dd.BabelNamed):
     """
     Default values filled from :mod:`lino_welfare.modlib.cbss.fixtures.sectors`.
     """
@@ -267,14 +264,14 @@ class Sector(babel.BabelNamed):
     #~ code = models.CharField(max_length=2,verbose_name=_("Code"),primary_key=True)
     code = models.IntegerField(max_length=2,verbose_name=_("Code"))
     subcode = models.IntegerField(max_length=2,verbose_name=_("Subcode"),default=0)
-    abbr = babel.BabelCharField(_("Abbreviation"),max_length=50,blank=True)
+    abbr = dd.BabelCharField(_("Abbreviation"),max_length=50,blank=True)
     
     
     def __unicode__(self):
-        #~ return '(' + str(self.code) + ') ' + babel.BabelNamed.__unicode__(self)
+        #~ return '(' + str(self.code) + ') ' + dd.BabelNamed.__unicode__(self)
         if self.subcode != 0:
-            return str(self.code) + '.' + str(self.subcode) + ' - ' + babel.BabelNamed.__unicode__(self)
-        return str(self.code) + ' - ' + babel.BabelNamed.__unicode__(self)
+            return str(self.code) + '.' + str(self.subcode) + ' - ' + dd.BabelNamed.__unicode__(self)
+        return str(self.code) + ' - ' + dd.BabelNamed.__unicode__(self)
         
 
 class Sectors(dd.Table):
@@ -286,7 +283,7 @@ class Sectors(dd.Table):
     order_by = ['code','subcode']
     
 
-class Purpose(babel.BabelNamed):
+class Purpose(dd.BabelNamed):
     u"""
     Codes qualité (Hoedanigheidscodes). 
     This table is usually filled with the official codes
@@ -303,8 +300,8 @@ class Purpose(babel.BabelNamed):
     code = models.IntegerField(max_length=3,verbose_name=_("Code"))
     
     def __unicode__(self):
-        #~ return '(' + str(self.code) + ') ' + babel.BabelNamed.__unicode__(self)
-        return str(self.code) + ' - ' + babel.BabelNamed.__unicode__(self)
+        #~ return '(' + str(self.code) + ') ' + dd.BabelNamed.__unicode__(self)
+        return str(self.code) + ' - ' + dd.BabelNamed.__unicode__(self)
         
 
 class Purposes(dd.Table):
@@ -388,7 +385,7 @@ The raw XML response received.
     
     #~ def save(self,*args,**kw):
         #~ if not self.environment:
-            #~ self.environment = settings.LINO.cbss_environment or ''
+            #~ self.environment = settings.SITE.cbss_environment or ''
         #~ super(CBSSRequest,self).save(*args,**kw)
 
     #~ def disable_editing(self,ar):
@@ -402,6 +399,7 @@ The raw XML response received.
         Note that also the `user` will be set to the user who asked to duplicate
         (because this is a subclass of :mod:`lino.mixins.UserAuthored`.
         """
+        self.user = ar.get_user()
         self.debug_messages = ''
         self.info_messages = ''
         self.ticket = ''
@@ -409,7 +407,7 @@ The raw XML response received.
         self.request_xml = ''
         self.sent = None
         #~ self.status = RequestStates.new
-        self.status = RequestStates.blank_item
+        self.status = '' # RequestStates.blank_item
         self.environment = ''
         super(CBSSRequest,self).on_duplicate(ar,master)
         
@@ -483,7 +481,7 @@ The raw XML response received.
         if now is None:
             now = datetime.datetime.now()
         if environment is None:
-            environment = settings.LINO.cbss_environment or ''
+            environment = settings.SITE.cbss_environment or ''
             
         self.environment = environment
         self.sent = now
@@ -491,7 +489,7 @@ The raw XML response received.
         self.debug_messages = ''
         self.info_messages = ''
         
-        if not settings.LINO.cbss_live_tests:
+        if not settings.SITE.cbss_live_tests:
             if simulate_response is None and environment:
                 self.validate_request()
                 self.status = RequestStates.validated
@@ -503,7 +501,7 @@ The raw XML response received.
         
         retval = None
         try:
-            #~ if not settings.LINO.cbss_live_tests:
+            #~ if not settings.SITE.cbss_live_tests:
                 #~ self.validate_request()
             retval = self.execute_request_(now,simulate_response)
         except (IOError,Warning),e:
@@ -689,7 +687,7 @@ class SSDNRequest(CBSSRequest):
             xmlString = unicode(wrapped_srvreq)
             self.request_xml = xmlString
             #~ logger.info("20120521 Gonna sendXML(<xmlString>):\n%s",xmlString)
-            if not settings.LINO.cbss_live_tests:
+            if not settings.SITE.cbss_live_tests:
                 #~ raise Warning("NOT sending because `cbss_live_tests` is False:\n" + unicode(xmlString))
                 raise Warning(
                     "NOT sending because `cbss_live_tests` is False:\n" + xmlString)
@@ -774,9 +772,9 @@ class SSDNRequest(CBSSRequest):
         by adding AuthorizedUser and other information common 
         the all SSDN requests).
         """
-        #~ up  = settings.LINO.ssdn_user_params
-        #~ user_params = settings.LINO.cbss_user_params
-        sc = settings.LINO.site_config
+        #~ up  = settings.SITE.ssdn_user_params
+        #~ user_params = settings.SITE.cbss_user_params
+        sc = settings.SITE.site_config
         #~ au = E('common:AuthorizedUser',ns=NSCOMMON)
         #~ au.append(E('common:UserID').setText(up['UserID']))
         #~ au.append(E('common:Email').setText(up['Email']))
@@ -838,10 +836,10 @@ class NewStyleRequest(CBSSRequest):
         url = self.get_wsdl_uri()
         
         #~ logger.info("Instantiate Client at %s", url)
-        sc = settings.LINO.site_config
+        sc = settings.SITE.site_config
         #~ t = HttpAuthenticated(
-            #~ username=settings.LINO.cbss_username, 
-            #~ password=settings.LINO.cbss_password)
+            #~ username=settings.SITE.cbss_username, 
+            #~ password=settings.SITE.cbss_password)
         t = HttpAuthenticated(
             username=sc.cbss_http_username, 
             password=sc.cbss_http_password)
@@ -853,12 +851,12 @@ class NewStyleRequest(CBSSRequest):
       
         client = get_client(self)
 
-        #~ sc = settings.LINO.site_config
+        #~ sc = settings.SITE.site_config
         ci = client.factory.create('ns0:CustomerIdentificationType')
         #~ cbeNumber = client.factory.create('ns0:CbeNumberType')
-        #~ ci.cbeNumber = settings.LINO.cbss_cbe_number
-        #~ ci.cbeNumber = settings.LINO.site_config.site_company.vat_id
-        ci.cbeNumber = settings.LINO.site_config.cbss_org_unit
+        #~ ci.cbeNumber = settings.SITE.cbss_cbe_number
+        #~ ci.cbeNumber = settings.SITE.site_config.site_company.vat_id
+        ci.cbeNumber = settings.SITE.site_config.cbss_org_unit
         info = client.factory.create('ns0:InformationCustomerType')
         info.ticket = str(self.id)
         info.timestampSent = now
@@ -954,7 +952,7 @@ class SSIN(dd.Model):
         #~ super(SSIN,self).save(*args,**kw)
         
     def on_create(self,ar):
-        #~ print '20120629 SSIN.on_create', obj2str(self), ar
+        #~ print '20120629 SSIN.on_create', dd.obj2str(self), ar
         #~ super(ContractBase,self).on_create(request)
         self.person_changed(ar)
         super(SSIN,self).on_create(ar)
@@ -1342,7 +1340,7 @@ class IdentifyPersonResult(dd.VirtualTable):
         
         
             
-    #~ @dd.virtualfield(models.ForeignKey(settings.LINO.person_model))
+    #~ @dd.virtualfield(models.ForeignKey(settings.SITE.person_model))
     #~ @dd.displayfield(_("Person"))
     #~ def person(self,obj,ar):
         #~ from lino.apps.pcsw.models import Person
@@ -1474,13 +1472,13 @@ for register/unregister it is mandatory.""")
 
     def save(self,*args,**kw):
         if not self.sector_id:
-            self.sector = settings.LINO.site_config.sector
+            self.sector = settings.SITE.site_config.sector
         super(ManageAccessRequest,self).save(*args,**kw)
 
     @chooser()
     def purpose_choices(cls,sector):
         if not sector:
-            sector = settings.LINO.site_config.sector
+            sector = settings.SITE.site_config.sector
         if not sector:
             raise Exception("SiteConfig.sector is not set!")
         Q = models.Q
@@ -1635,8 +1633,9 @@ class MyManageAccessRequests(ManageAccessRequests,mixins.ByUser):
 
 from lino_welfare.modlib.cbss.tx25 import *
     
-from lino.models import SiteConfig
-dd.inject_field(SiteConfig,
+from lino.ui.models import SiteConfig
+
+dd.inject_field('ui.SiteConfig',
     'sector',
     models.ForeignKey(Sector,
         blank=True,null=True,
@@ -1650,7 +1649,7 @@ for the non-editable field `sector`
 (which defines the choices of the `purpose` field).
 """))
     
-dd.inject_field(SiteConfig,
+dd.inject_field('ui.SiteConfig',
     'cbss_org_unit',
     models.CharField(_("Requesting organisation"),
       max_length=50,
@@ -1663,7 +1662,7 @@ For PCSWs this is the enterprise number
 Used in SSDN requests as text of the `AuthorizedUser\OrgUnit` element . 
 Used in new style requests as text of the `CustomerIdentification\cbeNumber` element . 
 """))
-dd.inject_field(SiteConfig,
+dd.inject_field('ui.SiteConfig',
     'ssdn_user_id',
     models.CharField(_("SSDN User Id"),
       max_length=50,
@@ -1671,14 +1670,14 @@ dd.inject_field(SiteConfig,
       help_text="""\
 Used in SSDN requests as text of the `AuthorizedUser\UserID` element.
 """))
-dd.inject_field(SiteConfig,
+dd.inject_field('ui.SiteConfig',
     'ssdn_email',
     models.EmailField(_("SSDN email address"),
       blank=True,
       help_text="""\
 Used in SSDN requests as text of the `AuthorizedUser\Email` element.
 """))
-dd.inject_field(SiteConfig,
+dd.inject_field('ui.SiteConfig',
     'cbss_http_username',
     models.CharField(_("HTTP username"),
       max_length=50,
@@ -1686,7 +1685,7 @@ dd.inject_field(SiteConfig,
       help_text="""\
 Used in the http header of new-style requests.
 """))
-dd.inject_field(SiteConfig,
+dd.inject_field('ui.SiteConfig',
     'cbss_http_password',
     models.CharField(_("HTTP password"),
       max_length=50,
@@ -1732,25 +1731,25 @@ dd.inject_field(pcsw.Client,
 
 MODULE_LABEL = _("CBSS")
 
-#~ settings.LINO.add_user_field('cbss_level',UserLevels.field(MODULE_LABEL))
-#~ settings.LINO.add_user_group('cbss',MODULE_LABEL)
-#~ settings.LINO.add_user_field('cbss_level',UserLevels.field(MODULE_LABEL))
+#~ settings.SITE.add_user_field('cbss_level',UserLevels.field(MODULE_LABEL))
+#~ settings.SITE.add_user_group('cbss',MODULE_LABEL)
+#~ settings.SITE.add_user_field('cbss_level',UserLevels.field(MODULE_LABEL))
 
-dd.inject_field('countries.City',
-    'inscode',
-    models.CharField(
-        max_length=5,
-        verbose_name=_("INS code"),
-        blank=True,
-    ))
+#~ dd.inject_field('countries.City',
+    #~ 'inscode',
+    #~ models.CharField(
+        #~ max_length=5,
+        #~ verbose_name=_("INS code"),
+        #~ blank=True,
+    #~ ))
         
-dd.inject_field('countries.Country',
-    'inscode',
-    models.CharField(
-        max_length=3,
-        verbose_name=_("INS code"),
-        blank=True,
-    ))
+#~ dd.inject_field('countries.Country',
+    #~ 'inscode',
+    #~ models.CharField(
+        #~ max_length=3,
+        #~ verbose_name=_("INS code"),
+        #~ blank=True,
+    #~ ))
         
 
 
@@ -1762,7 +1761,7 @@ def setup_site_cache(self,force):
     import logging
     logger = logging.getLogger(__name__)
     
-    environment = settings.LINO.cbss_environment
+    environment = settings.SITE.cbss_environment
     if not environment:
         return # silently return
         
@@ -1779,7 +1778,7 @@ def setup_site_cache(self,force):
                 return
         s = file(os.path.join(os.path.dirname(__file__),'WSDL',template)).read()
         s = s % context
-        makedirs_if_missing(os.path.dirname(fn))
+        settings.SITE.makedirs_if_missing(os.path.dirname(fn))
         open(fn,'wt').write(s)
         logger.info("Generated %s for environment %r.",fn,environment)
         
@@ -1823,7 +1822,7 @@ def site_setup(self):
     #~ self.modules.contacts.AllPersons.add_detail_tab('cbss',"cbssrequests",MODULE_LABEL,required_user_groups=['cbss'])
     #~ 
     
-    self.modules.lino.SiteConfigs.add_detail_tab('cbss',"""
+    self.modules.ui.SiteConfigs.add_detail_tab('cbss',"""
     cbss_org_unit sector ssdn_user_id ssdn_email
     cbss_http_username cbss_http_password
     """,MODULE_LABEL,required=dict(user_groups='cbss'))
