@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2011-2012 Luc Saffre
+## Copyright 2011-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -45,21 +45,20 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.utils.encoding import force_unicode
 
+from north import babel
+from north.babel import dtos
+
 
 from lino import mixins
 from lino import dd
 #~ from lino.utils import Warning
 from lino.utils import join_words
+from lino.utils import assert_pure
 from lino.utils import AttrDict, IncompleteDate
-from lino.core.modeltools import obj2str
-
-from lino.utils import babel
 
 from lino.utils.xmlgen import html as xghtml
 E = xghtml.E
 
-from lino.utils.babel import dtos
-
 
 
 try:
@@ -71,6 +70,18 @@ except ImportError, e:
 from lino_welfare.modlib.cbss.models import NewStyleRequest,SSIN, get_client, \
   CBSSRequestDetail, CBSSRequests, cbss2gender, RequestStates, CBSS_ERROR_MESSAGE
   
+def reply_has_result(reply):
+    if reply.status.value == "NO_RESULT":
+        msg = CBSS_ERROR_MESSAGE % reply.status.code
+        keys = ('value','code','description')
+        msg += '\n'.join([
+            k+' : '+getattr(reply.status,k)
+                for k in keys])
+        for i in reply.status.information:
+            msg += "\n- %s = %s" % (i.fieldName,i.fieldValue)
+        raise Warning(msg)
+  
+  
 class RequestLanguages(dd.ChoiceList):
     verbose_name = _("Language")
 add = RequestLanguages.add_item
@@ -92,7 +103,7 @@ class RetrieveTIGroupsRequest(NewStyleRequest,SSIN):
     #~ language = babel.LanguageField()
     language = RequestLanguages.field(blank=True)
     history = models.BooleanField(
-        verbose_name=_("History"),default=False,
+        verbose_name=_("History"),default=True,
         help_text = "Whatever this means.")
         
     def get_print_language(self,pm):
@@ -106,13 +117,15 @@ class RetrieveTIGroupsRequest(NewStyleRequest,SSIN):
         
         
     def get_service_reply(self,**kwargs):
+        assert_pure(self.response_xml)
         client = get_client(self)
         meth = client.service.retrieveTI
         clientclass = meth.clientclass(kwargs)
         client = clientclass(meth.client, meth.method)
         #~ print 20120613, portSelector[0]
         #~ print '20120613b', dir(client)
-        return client.succeeded(client.method.binding.input, self.response_xml.encode('utf-8'))
+        s = self.response_xml.encode('utf-8')
+        return client.succeeded(client.method.binding.input,s)
         
     
     def execute_newstyle(self,client,infoCustomer,simulate_response):
@@ -164,23 +177,16 @@ class RetrieveTIGroupsRequest(NewStyleRequest,SSIN):
                 msg += unicode(e.document)
                 self.status = RequestStates.failed
                 raise Warning(msg)
-            self.response_xml = reply
+            self.response_xml = reply.decode('utf-8') # 20130201
         else:
             self.response_xml = simulate_response
             
         #~ self.response_xml = unicode(reply)
         reply = self.get_service_reply()
         self.ticket = reply.informationCBSS.ticketCBSS
-        if reply.status.value == "NO_RESULT":
-            msg = CBSS_ERROR_MESSAGE % reply.status.code
-            keys = ('value','code','description')
-            msg += '\n'.join([
-                k+' : '+getattr(reply.status,k)
-                    for k in keys])
-            for i in reply.status.information:
-                msg += "\n- %s = %s" % (i.fieldName,i.fieldValue)
-            self.status = RequestStates.warnings
-            raise Warning(msg)
+        self.status = RequestStates.warnings
+        
+        reply_has_result(reply)
             
         self.status = RequestStates.ok
         #~ self.response_xml = str(res)
@@ -263,8 +269,13 @@ def simpletype(v):
 def boldstring(v):
     return Info(xghtml.E.b(unicode(v)))
     
+def validate_element(c):
+    if c is None:
+        raise Exception("Invalid element %r" % c)
+        
 class Info(object):
     def __init__(self,*chunks):
+        for c in chunks: validate_element(c)
         self.chunks = list(chunks)
     def addfrom(self,node,name,prefix=None,fmt=boldstring,suffix=''):
         v = getattr(node,name,None)
@@ -498,14 +509,59 @@ def IT024(n):
     info = Info()
     info.add_deldate(n)
     return info
-  
+
+def IT208(n):
+    info = Info()
+    #~ info.addfrom(n,'Date','',DateType)
+    info.addfrom(n,'PseudoNationalNumber','')
+    info.add_deldate(n)
+    return info
+
+
+def IT073(n):
+    info = Info()
+    info.addfrom(n,'Category','',CategoryType)
+    info.addfrom(n,'CertificateNumber',_("no."))
+    info.add_deldate(n)
+    return info
+
+def IT074(n):
+    info = Info()
+    info.addfrom(n,'SerialNumber')
+    info.addfrom(n,'IdentificationNumber')
+    info.add_deldate(n)
+    return info
+
+
 def FiliationType(n):
     return code_label(n)
+
 def ParentType(n):
     info = Info()
     info.addfrom(n,'Name','',NameType)
     info.addfrom(n,'NationalNumber',' (',NationalNumberType,')')
     return info
+    
+def StreetType(n):
+    # we don't print the code of streets
+    info = Info()
+    info.addfrom(n,'Label','')
+    #~ info.addfrom(n,'NationalNumber',' (',NationalNumberType,')')
+    return info
+    #~ return code_label(n)
+
+def IT020(n):
+    def AddressType020(n):
+        info = Info()
+        info.addfrom(n,'ZipCode','')
+        info.addfrom(n,'Street','',StreetType)
+        info.addfrom(n,'HouseNumber',_('no. '))
+        info.addfrom(n,'Box',' ')
+        return info
+    info = Info()
+    info.addfrom(n,"Address",'',AddressType020)
+    return info
+  
 def IT110(n):
     #~ info = code_label(n.FiliationType)
     #~ info.addfrom(n.Parent1,'Name','',NameType)
@@ -988,14 +1044,16 @@ class RowHandlers:
     def LegalMainAddresses(node,name):
         group = _("Legal Main Addresses")
         for n in node.LegalMainAddress:
-            info = Info()
-            info.chunks.append(E.b(n.Address.ZipCode))
-            info.chunks.append(', ')
-            info.chunks.append(n.Address.Street.Label)
-            info.chunks.append(' ')
-            info.chunks.append(n.Address.HouseNumber)
-            yield datarow(group,n,n.Date,info)
+            yield datarow(group,n,n.Date,IT020(n))
             group = ''
+            #~ info = Info()
+            #~ info.chunks.append(E.b(n.Address.ZipCode))
+            #~ info.chunks.append(', ')
+            #~ info.chunks.append(n.Address.Street.Label)
+            #~ info.chunks.append(' ')
+            #~ info.chunks.append(n.Address.HouseNumber)
+            #~ yield datarow(group,n,n.Date,info)
+            #~ group = ''
             
 
     @staticmethod
@@ -1290,6 +1348,30 @@ class RowHandlers:
             yield datarow(group,n,n.Date,info)
             group = ''
         
+    @staticmethod
+    def PseudoNationalNumbers(node,name):
+        group = _("Pseudo National Numbers") # Pseudo-numéro national
+        for n in node.PseudoNationalNumber:
+            info = IT208(n)
+            yield datarow(group,n,n.Date,info)
+            group = ''
+        
+    @staticmethod
+    def RetirementCertificates(node,name):
+        group = _("Retirement Certificates") # Certificats de pension
+        for n in node.RetirementCertificate:
+            info = IT073(n)
+            yield datarow(group,n,n.Date,info)
+            group = ''
+        
+    @staticmethod
+    def SpecialRetirementCertificates(node,name):
+        group = _("Special Retirement Certificates") # Certificats de pension spéciale
+        for n in node.SpecialRetirementCertificate:
+            info = IT074(n)
+            yield datarow(group,n,n.Date,info)
+            group = ''
+        
     @staticmethod
     def IT253(node,name):
         group = _("Creation Date")
@@ -1343,15 +1425,16 @@ class RetrieveTIGroupsResult(dd.VirtualTable):
         reply = rti.get_service_reply()
         if reply is None:
             return
-            
-            
+        reply_has_result(reply)
+        
         res = reply.rrn_it_implicit
         
         for name, node in res:
             #~ print name, node.__class__
             m = getattr(RowHandlers,node.__class__.__name__,None)
             if m is None:
-                raise Exception("No handler for %s (%s)" % (name, node.__class__.__name__))
+                raise Exception("No handler for %s (%s)" 
+                    % (name, node.__class__.__name__))
             else:
                 for row in m(node,name): yield row
             
