@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2012 Luc Saffre
+## Copyright 2012-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -28,9 +28,8 @@ from django.db import IntegrityError
 from django.utils.encoding import force_unicode
 
 
-from lino import tools
 from lino import dd
-from lino.core import changes
+#~ from lino.core import changes
 #~ from lino.utils.babel import default_language
 #~ from lino import reports
 #~ from lino import layouts
@@ -39,7 +38,7 @@ from lino.utils.restify import restify
 #~ from lino.utils import printable
 
 from lino.utils.choosers import chooser
-from lino.utils import babel
+from north import babel
 from lino.utils import ssin
 from lino.utils import workdays
 from lino import mixins
@@ -95,7 +94,7 @@ class Brokers(dd.Table):
 
 
 
-class Faculty(babel.BabelNamed):
+class Faculty(dd.BabelNamed):
     """
     A Faculty (Fachbereich) is a conceptual (not organizational)
     department of this PCSW. 
@@ -106,7 +105,7 @@ class Faculty(babel.BabelNamed):
     class Meta:
         verbose_name = _("Faculty")
         verbose_name_plural = _("Faculties")
-    #~ body = babel.BabelTextField(_("Body"),blank=True,format='html')
+    #~ body = dd.BabelTextField(_("Body"),blank=True,format='html')
     weight = models.IntegerField(
           _("Work effort"), # Arbeitsaufwand
           default=MAX_WEIGHT,
@@ -325,6 +324,7 @@ class AvailableCoaches(users.Users):
     """
     use_as_default_table = False
     required = dict(user_groups='newcomers')
+    auto_fit_column_widths = True
     #~ required_user_groups = ['newcomers']
     #~ model = users.User
     editable = False # even root should not edit here
@@ -359,8 +359,8 @@ class AvailableCoaches(users.Users):
         if client:
             if client.client_state != pcsw.ClientStates.newcomer:
                 raise Warning(_("Only for newcomers"))
-            if not client.national_id:
-                raise Warning(_("Only for newcomers with valid SSIN"))
+            #~ if not client.national_id:
+                #~ raise Warning(_("Only for newcomers with valid SSIN"))
             #~ if not ssin.is_valid_ssin(client.national_id):
                 #~ raise Warning(_("Only for newcomers with valid SSIN"))
             if not client.faculty:
@@ -518,7 +518,7 @@ nicht mehr angezeigt."""
         Assign a coach to a newcomer.
         """
         client = ar.master_instance
-        watcher = changes.Watcher(client)
+        watcher = dd.ChangeWatcher(client)
         #~ if not ssin.is_valid_ssin(client.national_id):
             #~ return ar.error_response(alert=True,
                 #~ message=_("Cannot assign client %(client)s with invalid SSIN %(ssin)s.") 
@@ -533,11 +533,12 @@ nicht mehr angezeigt."""
         #~ if not obj.profile:
             #~ coaching.state = pcsw.CoachingStates.active
         coaching.save()
-        changes.log_create(ar.request,coaching)
+        dd.pre_ui_create.send(coaching,request=ar.request)
+        #~ changes.log_create(ar.request,coaching)
         client.client_state = pcsw.ClientStates.coached
         client.full_clean()
         client.save()
-        watcher.log_diff(ar.request)
+        watcher.send_update(ar.request)
         
         self.add_system_note(ar,coaching)
         
@@ -593,7 +594,7 @@ class AvailableCoachesByClient(AvailableCoaches):
         #~ recipients = []
         #~ recipients.append(
             #~ dict(name=unicode(obj),address=obj.email,type=outbox.RecipientType.to))
-        #~ for u in settings.LINO.user_model.objects.filter(coaching_supervisor=True):
+        #~ for u in settings.SITE.user_model.objects.filter(coaching_supervisor=True):
             #~ recipients.append(
                 #~ dict(name=unicode(u),address=u.email,type=outbox.RecipientType.to))
             
@@ -633,9 +634,9 @@ class AvailableCoachesByClient(AvailableCoaches):
 
 
 
-#~ settings.LINO.add_user_field('newcomers_level',UserLevels.field(MODULE_LABEL))
-#~ settings.LINO.add_user_group('newcomers',MODULE_LABEL)
-settings.LINO.add_user_field('newcomer_quota',models.IntegerField(
+#~ settings.SITE.add_user_field('newcomers_level',UserLevels.field(MODULE_LABEL))
+#~ settings.SITE.add_user_group('newcomers',MODULE_LABEL)
+settings.SITE.add_user_field('newcomer_quota',models.IntegerField(
           _("Newcomers Quota"),
           default=0,
           help_text=u"""\
