@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2008-2011 Luc Saffre
+## Copyright 2008-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -15,16 +15,17 @@
 
 from django.contrib.contenttypes.models import ContentType
 from lino.utils.instantiator import Instantiator, i2d
-from lino.core.modeltools import resolve_model
+from lino.core.dbutils import resolve_model
 from django.utils.translation import ugettext_lazy as _
 
 
 from django.db import models
 from django.conf import settings
-from lino.utils.babel import babel_values, babelitem
 
-Person = resolve_model(settings.LINO.person_model)
-Company = resolve_model(settings.LINO.company_model)
+from north.babel import babel_values, babelitem
+
+Person = resolve_model('contacts.Person')
+Company = resolve_model('contacts.Company')
 ExclusionType = resolve_model('pcsw.ExclusionType')
 
 #~ from lino.modlib.properties import models as properties 
@@ -152,9 +153,7 @@ def objects():
     yield excltype(u"ONEM-Auflagen nicht erfüllt")
     
     #~ linkType = Instantiator('links.LinkType',"a_type b_type name").build
-    Company = resolve_model(settings.LINO.company_model)
-    Person = resolve_model(settings.LINO.person_model)
-    
+   
     #~ yield linkType(
         #~ ContentType.objects.get_for_model(Company),
         #~ ContentType.objects.get_for_model(Person),
@@ -178,14 +177,19 @@ def objects():
     yield uploadType(babelitem(de=u"Personalausweis",fr=u"Carte d'identité",en="ID card"))
     p = uploadType(babelitem(de=u"Aufenthaltserlaubnis",fr=u"Permis de séjour",en="Residence permit"))
     yield p
-    settings.LINO.update_site_config(residence_permit_upload_type=p)
+    #~ settings.SITE.update_site_config(residence_permit_upload_type=p)
+    settings.SITE.site_config.residence_permit_upload_type = p
     p = uploadType(babelitem(de=u"Arbeitserlaubnis",fr=u"Permis de travail",en="Work permit"))
     yield p
-    settings.LINO.update_site_config(work_permit_upload_type = p)
+    #~ settings.SITE.update_site_config(work_permit_upload_type = p)
+    settings.SITE.site_config.work_permit_upload_type = p
     yield uploadType(babelitem(de=u"Vertrag",fr=u"Contrat",en="Contract"))
     p = uploadType(babelitem(de=u"Führerschein",fr=u"Permis de conduire",en="Diving licence"))
     yield p
-    settings.LINO.update_site_config(driving_licence_upload_type = p)
+    #~ settings.SITE.update_site_config(driving_licence_upload_type = p)
+    settings.SITE.site_config.driving_licence_upload_type = p
+    
+    yield settings.SITE.site_config
     
     
     from lino.modlib.cal.utils import DurationUnits
@@ -263,7 +267,7 @@ def objects():
       en=u"Autre aide sociale",
       ))
     
-    I = Instantiator('lino.HelpText','content_type field help_text').build
+    I = Instantiator('ui.HelpText','content_type field help_text').build
     
     Client = resolve_model('pcsw.Client')
     t = ContentType.objects.get_for_model(Client)
